Crate asimov_protocol

Crate asimov_protocol 

Modules

node_state
peer_accept_state
peer_connect_state
peer_connection_state

Structs

CsvHandleResolvercsv and std
A CSV file resolver from ASIMOV handles to peer IDs.
DefaultPreset
The default preset for ASIMOV.
Endpoint
Controls an iroh endpoint, establishing connections with other endpoints.
EndpointAddr
Network-level addressing information for an iroh endpoint.
EndpointTicket
A token containing information for establishing a connection to an endpoint.
GossipProtocol
The gossip protocol for use with Router.
GossipReceiver
Receiver for gossip events on a topic.
GossipSender
Sender for a gossip topic.
GossipTopic
Subscribed gossip topic.
Handle
Node
NodeMetrics
Metrics for the node protocol.
NodeProtocol
The node protocol for use with Router.
PeerAccept
PeerConnect
PeerConnection
PeerHello
PublicKey
Router
The built router.
RouterBuilder
Builder for creating a Router for accepting protocols.
SecretKey
A secret key.
TopicId
The identifier for a topic
TopicSubscription

Enums

AcceptError
BindError
ConnectError
FeatureIter
HandleError
Id
IdError
KeyError
Message
NodeFeatureSet
PingError
PublicKeyEncoding
PublishError
RecvError
SendError
StartError
SubscribeError
TerminateError
TicketParsingError
An error deserializing an iroh ticket.
Topic

Constants

CURRENT_VERSION
GOSSIP_ALPN
The ALPN string for the gossip protocol.
MAXIMUM_VERSION
MESSAGE_HEADER_LEN
MINIMUM_VERSION
NODE_ALPN
The ALPN string for the node protocol.
REQUIRED_FEATURES
SUPPORTED_FEATURES

Traits

MessageRecv
MessageSend
Preset
A reusable bundle of endpoint Builder configuration.
ResolveHandle
A resolver for ASIMOV handles (e.g., “Ⓐjhacker”).
Stream
A stream of values produced asynchronously.
StreamExt
Extension trait for Stream.
Ticket
A ticket is a serializable object combining information required for an operation.

Type Aliases

EndpointId
The identifier for an endpoint in the (iroh) network.
MessageLen
PeerId
A peer ID.