pub struct EndpointTicket { /* private fields */ }Expand description
A token containing information for establishing a connection to an endpoint.
Contains
- The
EndpointIdof the endpoint to connect to (a 32-byte ed25519 public key). - Any known
TransportAddrs on which the endpoint can be reached.
This allows establishing a connection to the endpoint in most circumstances where it is possible to do so.
This EndpointTicket is a single item which can be easily serialized and deserialized
and implements the Ticket trait. The Display and FromStr traits round-trip
the canonical string form via Ticket::encode_string / Ticket::decode_string.
Implementations
Sourceimpl EndpointTicket
impl EndpointTicket
Sourcepub fn new(addr: EndpointAddr) -> EndpointTicket
pub fn new(addr: EndpointAddr) -> EndpointTicket
Creates a new ticket.
Sourcepub fn endpoint_addr(&self) -> &EndpointAddr
pub fn endpoint_addr(&self) -> &EndpointAddr
The EndpointAddr of the provider for this ticket.